summaryrefslogtreecommitdiff
path: root/sd/source/ui/view/drbezob.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/view/drbezob.cxx')
-rwxr-xr-x[-rw-r--r--]sd/source/ui/view/drbezob.cxx26
1 files changed, 13 insertions, 13 deletions
diff --git a/sd/source/ui/view/drbezob.cxx b/sd/source/ui/view/drbezob.cxx
index ae512b0441d9..0d7bcfb47ad3 100644..100755
--- a/sd/source/ui/view/drbezob.cxx
+++ b/sd/source/ui/view/drbezob.cxx
@@ -125,7 +125,7 @@ void BezierObjectBar::GetAttrState(SfxItemSet& rSet)
{
SfxItemSet aAttrSet( mpView->GetDoc()->GetPool() );
mpView->GetAttributes( aAttrSet );
- rSet.Put(aAttrSet, FALSE); // <- FALSE, damit DontCare-Status uebernommen wird
+ rSet.Put(aAttrSet, sal_False); // <- sal_False, damit DontCare-Status uebernommen wird
FunctionReference xFunc( mpViewSh->GetCurrentFunction() );
@@ -133,13 +133,13 @@ void BezierObjectBar::GetAttrState(SfxItemSet& rSet)
{
if(xFunc->ISA(FuSelection))
{
- USHORT nEditMode = static_cast<FuSelection*>(xFunc.get())->GetEditMode();
- rSet.Put(SfxBoolItem(nEditMode, TRUE));
+ sal_uInt16 nEditMode = static_cast<FuSelection*>(xFunc.get())->GetEditMode();
+ rSet.Put(SfxBoolItem(nEditMode, sal_True));
}
else if (xFunc->ISA(FuConstructBezierPolygon))
{
- USHORT nEditMode = static_cast<FuConstructBezierPolygon*>(xFunc.get())->GetEditMode();
- rSet.Put(SfxBoolItem(nEditMode, TRUE));
+ sal_uInt16 nEditMode = static_cast<FuConstructBezierPolygon*>(xFunc.get())->GetEditMode();
+ rSet.Put(SfxBoolItem(nEditMode, sal_True));
}
}
@@ -187,8 +187,8 @@ void BezierObjectBar::GetAttrState(SfxItemSet& rSet)
switch (eSegm)
{
case SDRPATHSEGMENT_DONTCARE: rSet.InvalidateItem(SID_BEZIER_CONVERT); break;
- case SDRPATHSEGMENT_LINE : rSet.Put(SfxBoolItem(SID_BEZIER_CONVERT,FALSE)); break; // Button reingedrueckt = Kurve
- case SDRPATHSEGMENT_CURVE : rSet.Put(SfxBoolItem(SID_BEZIER_CONVERT,TRUE)); break;
+ case SDRPATHSEGMENT_LINE : rSet.Put(SfxBoolItem(SID_BEZIER_CONVERT,sal_False)); break; // Button reingedrueckt = Kurve
+ case SDRPATHSEGMENT_CURVE : rSet.Put(SfxBoolItem(SID_BEZIER_CONVERT,sal_True)); break;
default: break;
}
}
@@ -204,9 +204,9 @@ void BezierObjectBar::GetAttrState(SfxItemSet& rSet)
switch (eSmooth)
{
case SDRPATHSMOOTH_DONTCARE : break;
- case SDRPATHSMOOTH_ANGULAR : rSet.Put(SfxBoolItem(SID_BEZIER_EDGE, TRUE)); break;
- case SDRPATHSMOOTH_ASYMMETRIC: rSet.Put(SfxBoolItem(SID_BEZIER_SMOOTH,TRUE)); break;
- case SDRPATHSMOOTH_SYMMETRIC : rSet.Put(SfxBoolItem(SID_BEZIER_SYMMTR,TRUE)); break;
+ case SDRPATHSMOOTH_ANGULAR : rSet.Put(SfxBoolItem(SID_BEZIER_EDGE, sal_True)); break;
+ case SDRPATHSMOOTH_ASYMMETRIC: rSet.Put(SfxBoolItem(SID_BEZIER_SMOOTH,sal_True)); break;
+ case SDRPATHSMOOTH_SYMMETRIC : rSet.Put(SfxBoolItem(SID_BEZIER_SYMMTR,sal_True)); break;
}
}
if (!pIPPEC || !pIPPEC->IsOpenCloseMarkedObjectsPossible())
@@ -219,8 +219,8 @@ void BezierObjectBar::GetAttrState(SfxItemSet& rSet)
switch (eClose)
{
case SDROBJCLOSED_DONTCARE: rSet.InvalidateItem(SID_BEZIER_CLOSE); break;
- case SDROBJCLOSED_OPEN : rSet.Put(SfxBoolItem(SID_BEZIER_CLOSE,FALSE)); break;
- case SDROBJCLOSED_CLOSED : rSet.Put(SfxBoolItem(SID_BEZIER_CLOSE,TRUE)); break;
+ case SDROBJCLOSED_OPEN : rSet.Put(SfxBoolItem(SID_BEZIER_CLOSE,sal_False)); break;
+ case SDROBJCLOSED_CLOSED : rSet.Put(SfxBoolItem(SID_BEZIER_CLOSE,sal_True)); break;
default: break;
}
}
@@ -241,7 +241,7 @@ void BezierObjectBar::GetAttrState(SfxItemSet& rSet)
void BezierObjectBar::Execute(SfxRequest& rReq)
{
- USHORT nSId = rReq.GetSlot();
+ sal_uInt16 nSId = rReq.GetSlot();
switch (nSId)
{